:orphan:

WAMP Features
=============

The Web Application Messaging Protocol (WAMP) enables both the Publish &
Subscribe and the routed Remote Procedure Calls messaging pattern in a
single protocol.

To learn more:

-  Session
-  :doc:`Session Meta Events and Procedures <Session-Metaevents-and-Procedures>`  
-  :doc:`Publish & Subscribe (PubSub) <PubSub>`  
-  :doc:`How Subscriptions Work <How-Subscriptions-Work>`  
-  :doc:`Basic Subscriptions <Basic-Subscriptions>`  
-  :doc:`Subscriber Black- and Whitelisting <Subscriber-Black-and-Whitelisting>`  
-  :doc:`Publisher Exclusion <Publisher-Exclusion>`  
-  :doc:`Publisher Identification <Publisher-Identification>`  
-  :doc:`Pattern-Based Subscriptions <Pattern-Based-Subscriptions>`  
-  :doc:`Subscription Meta Events and Procedures <Subscription-Meta-Events-and-Procedures>`  
-  :doc:`Event History <Event-History>`  
-  :doc:`Remote Procedure Calls <RPC>`  
-  :doc:`How Registrations Work <How-Registrations-Work>`  
-  :doc:`Basic Registrations <Basic-Registrations>`  
-  :doc:`Caller Identification <Caller-Identification>`  
-  :doc:`Progressive Call Results <Progressive-Call-Results>`  
-  :doc:`Pattern-Based Registrations <Pattern-Based-Registrations>`  
-  :doc:`Shared Registrations <Shared-Registrations>`  
-  :doc:`Registration Meta Events and Procedures <Registration-Meta-Events-and-Procedures>`  
-  :doc:`Error Handling <Error-Handling>`  
-  :doc:`URI Format <URI-Format>`  
